@@ -10,7 +10,7 @@ make_params <- function(params, by, ok="") {
 
 }
 
-clean_cols <- function(x) {
+.clean_cols <- function(x) {
 
   x <- stringi::stri_replace_all_fixed(x, ",", "")
 
@@ -23,3 +23,9 @@ clean_cols <- function(x) {
   }
 
 }
+
+clean_cols <- function(x) {
+  suppressWarnings(
+    .clean_cols(x)
+  )
+}
\ No newline at end of file
